import { max, min } from 'd3-array';
import { scaleLinear, scaleOrdinal } from 'd3-scale';
import { schemeSet1 } from 'd3-scale-chromatic';
import React, { useReducer } from 'react';
import { PlotContext, DispatchContext } from './hooks';
import { splitChildren } from './utils';
function reducer(state, action) {
    switch (action.type) {
        case 'newData': {
            const { series } = state;
            const serieItem = action.value;
            return { series: [...series, serieItem] };
        }
        case 'removeData': {
            const { id } = action.value;
            const seriesFiltered = state.series.filter((series) => series.id !== id);
            return { series: seriesFiltered };
        }
        default: {
            throw new Error();
        }
    }
}
export default function Plot({ width, height, margin, colorScheme, children, }) {
    const [state, dispatch] = useReducer(reducer, { series: [] }, undefined);
    const compoundComp = splitChildren(children);
    const { invalidChild, lineSeries, axis, heading, legend } = compoundComp;
    if (invalidChild) {
        throw new Error('Only compound components of Plot are displayed');
    }
    // Set scales
    const xMin = min(state.series, (d) => d.xMin);
    const xMax = max(state.series, (d) => d.xMax);
    const yMin = min(state.series, (d) => d.yMin);
    const yMax = max(state.series, (d) => d.yMax);
    const xScale = ![xMin, xMax].includes(undefined)
        ? scaleLinear()
            .domain([xMin, xMax])
            .range([(margin === null || margin === void 0 ? void 0 : margin.left) || 0, width - ((margin === null || margin === void 0 ? void 0 : margin.right) || 0)])
        : null;
    const yScale = ![yMin, yMax].includes(undefined)
        ? scaleLinear()
            .domain([yMin, yMax])
            .range([height - ((margin === null || margin === void 0 ? void 0 : margin.bottom) || 0), (margin === null || margin === void 0 ? void 0 : margin.top) || 0])
        : null;
    const labels = state.series.map(({ label }) => label);
    const colorScaler = scaleOrdinal()
        .range(colorScheme || schemeSet1)
        .domain(labels);
    return (React.createElement(PlotContext.Provider, { value: { xScale, yScale, width, height, margin, labels, colorScaler } },
        React.createElement(DispatchContext.Provider, { value: { dispatch } },
            React.createElement("svg", { width: width, height: height },
                heading,
                legend,
                lineSeries,
                axis.x,
                axis.y))));
}
//# sourceMappingURL=Plot.js.map