import { axisBottom } from 'd3-axis';
import { select } from 'd3-selection';
import React, { useEffect, useRef } from 'react';
import { usePlotContext } from '../hooks';
const XAxis = ({ label, fontSize = 16, labelSpace = 20, showGridLines, labelStyle, tickFormat, }) => {
    const axisRef = useRef(null);
    const { xScale, margin, height, width } = usePlotContext();
    useEffect(() => {
        if ((axisRef === null || axisRef === void 0 ? void 0 : axisRef.current) && xScale) {
            const axis = axisBottom(xScale);
            if (showGridLines) {
                axis.tickSizeInner(((margin === null || margin === void 0 ? void 0 : margin.bottom) || 0) + ((margin === null || margin === void 0 ? void 0 : margin.top) || 0) - height);
            }
            if (tickFormat) {
                axis.tickFormat(tickFormat);
            }
            select(axisRef.current)
                .call(axis)
                .call((g) => {
                g.selectAll('.tick line')
                    .attr('stroke-opacity', showGridLines ? 0.5 : 1)
                    .attr('stroke-dasharray', showGridLines ? '2,2' : '0');
                g.selectAll('.tick text').attr('transform', `translate(0,${showGridLines ? 6 : 0})`);
            });
        }
    }, [axisRef, xScale, margin, height, width, showGridLines, tickFormat]);
    // Recomend bigger margin
    if (((margin === null || margin === void 0 ? void 0 : margin.left) || 0) < fontSize + labelSpace) {
        // eslint-disable-next-line no-console
        console.warn(`Your margin left should be at least ${fontSize + 20}`);
    }
    return (React.createElement(React.Fragment, null,
        React.createElement("g", { ref: axisRef, transform: `translate(0, ${height - ((margin === null || margin === void 0 ? void 0 : margin.bottom) || 0)})` }),
        label && (React.createElement("text", { transform: `translate(${width / 2} ,${height - ((margin === null || margin === void 0 ? void 0 : margin.bottom) || 0) + labelSpace + fontSize})`, fontSize: fontSize, textAnchor: "middle", style: { fontFamily: 'Arial, Helvetica, sans-serif', ...labelStyle } }, label))));
};
export default XAxis;
//# sourceMappingURL=XAxis.js.map