import { axisLeft } from 'd3-axis';
import { select } from 'd3-selection';
import React, { useEffect, useRef } from 'react';
import { usePlotContext } from '../hooks';
const YAxis = ({ label, fontSize = 16, labelSpace = 30, showGridLines, labelStyle, tickFormat, }) => {
    const axisRef = useRef(null);
    const { yScale, margin, height, width } = usePlotContext();
    useEffect(() => {
        if ((axisRef === null || axisRef === void 0 ? void 0 : axisRef.current) && yScale) {
            const axis = axisLeft(yScale);
            if (showGridLines) {
                axis.tickSizeInner(((margin === null || margin === void 0 ? void 0 : margin.left) || 0) + ((margin === null || margin === void 0 ? void 0 : margin.right) || 0) - width);
            }
            if (tickFormat) {
                axis.tickFormat(tickFormat);
            }
            select(axisRef.current)
                .call(axis)
                .call((g) => {
                g.selectAll('.tick line')
                    .attr('stroke-opacity', showGridLines ? 0.5 : 1)
                    .attr('stroke-dasharray', showGridLines ? '2,2' : '0');
                g.selectAll('.tick text').attr('transform', `translate(${showGridLines ? -6 : 0},0)`);
            });
        }
    }, [axisRef, yScale, margin, width, showGridLines, tickFormat]);
    // Recomend bigger margin
    if (((margin === null || margin === void 0 ? void 0 : margin.bottom) || 0) < fontSize + labelSpace) {
        // eslint-disable-next-line no-console
        console.warn(`Your margin bottom should be at least ${fontSize + labelSpace}`);
    }
    return (React.createElement(React.Fragment, null,
        React.createElement("g", { ref: axisRef, transform: `translate(${(margin === null || margin === void 0 ? void 0 : margin.left) || 0}, 0)` }),
        label && (React.createElement("text", { transform: `translate(${((margin === null || margin === void 0 ? void 0 : margin.left) || 0) - fontSize - labelSpace}, ${height / 2})rotate(-90)`, dy: fontSize, textAnchor: "middle", fontSize: fontSize, style: { fontFamily: 'Arial, Helvetica, sans-serif', ...labelStyle } }, label))));
};
export default YAxis;
//# sourceMappingURL=YAxis.js.map