"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const d3_array_1 = require("d3-array");
const d3_scale_1 = require("d3-scale");
const d3_scale_chromatic_1 = require("d3-scale-chromatic");
const react_1 = __importStar(require("react"));
const hooks_1 = require("./hooks");
const utils_1 = require("./utils");
function reducer(state, action) {
    switch (action.type) {
        case 'newData': {
            const { series } = state;
            const serieItem = action.value;
            return { series: [...series, serieItem] };
        }
        case 'removeData': {
            const { id } = action.value;
            const seriesFiltered = state.series.filter((series) => series.id !== id);
            return { series: seriesFiltered };
        }
        default: {
            throw new Error();
        }
    }
}
function Plot({ width, height, margin, colorScheme, children, }) {
    const [state, dispatch] = react_1.useReducer(reducer, { series: [] }, undefined);
    const compoundComp = utils_1.splitChildren(children);
    const { invalidChild, lineSeries, axis, heading, legend } = compoundComp;
    if (invalidChild) {
        throw new Error('Only compound components of Plot are displayed');
    }
    // Set scales
    const xMin = d3_array_1.min(state.series, (d) => d.xMin);
    const xMax = d3_array_1.max(state.series, (d) => d.xMax);
    const yMin = d3_array_1.min(state.series, (d) => d.yMin);
    const yMax = d3_array_1.max(state.series, (d) => d.yMax);
    const xScale = ![xMin, xMax].includes(undefined)
        ? d3_scale_1.scaleLinear()
            .domain([xMin, xMax])
            .range([(margin === null || margin === void 0 ? void 0 : margin.left) || 0, width - ((margin === null || margin === void 0 ? void 0 : margin.right) || 0)])
        : null;
    const yScale = ![yMin, yMax].includes(undefined)
        ? d3_scale_1.scaleLinear()
            .domain([yMin, yMax])
            .range([height - ((margin === null || margin === void 0 ? void 0 : margin.bottom) || 0), (margin === null || margin === void 0 ? void 0 : margin.top) || 0])
        : null;
    const labels = state.series.map(({ label }) => label);
    const colorScaler = d3_scale_1.scaleOrdinal()
        .range(colorScheme || d3_scale_chromatic_1.schemeSet1)
        .domain(labels);
    return (react_1.default.createElement(hooks_1.PlotContext.Provider, { value: { xScale, yScale, width, height, margin, labels, colorScaler } },
        react_1.default.createElement(hooks_1.DispatchContext.Provider, { value: { dispatch } },
            react_1.default.createElement("svg", { width: width, height: height },
                heading,
                legend,
                lineSeries,
                axis.x,
                axis.y))));
}
exports.default = Plot;
